@@ -20,6 +20,7 @@ const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const Gnome = imports.gi.GnomeDesktop;
 const GObject = imports.gi.GObject;
+const Gdk = imports.gi.Gdk;
 const Gtk = imports.gi.Gtk;
 const GWeather = imports.gi.GWeather;
 
@@ -39,7 +40,8 @@ var WeatherWidget = GObject.registerClass({
     InternalChildren: ['contentFrame', 'outerBox',
                        'conditionsImage', 'placesButton', 'placesLabel',
                        'temperatureLabel', 'apparentLabel',
-                       'forecastStack', 'leftBox', 'leftButton', 'rightBox', 'rightButton',
+                       'forecastFrame', 'forecastStack',
+                       'leftButton', 'rightButton',
                        'forecast-hourly', 'forecast-hourly-viewport',
                        'forecast-daily', 'forecast-daily-viewport',
                        'updatedTimeLabel', 'attributionLabel'],
@@ -61,9 +63,9 @@ var WeatherWidget = GObject.registerClass({
         for (let t of ['hourly', 'daily']) {
             let box;
             if (t == 'hourly') {
-                box = new HourlyForecast.HourlyForecastFrame();
+                box = new HourlyForecast.HourlyForecastBox();
             } else {
-                box = new DailyForecast.DailyForecastFrame();
+                box = new DailyForecast.DailyForecastBox();
             }
 
             this._forecasts[t] = box;
@@ -109,6 +111,30 @@ var WeatherWidget = GObject.registerClass({
             this._beginScrollAnimation(target);
         });
 
+        this._forecastFrame.connect('draw', (frame, cr) => {
+            const width = frame.get_allocated_width();
+            const height = frame.get_allocated_height();
+
+            const borderRadius = 8;
+
+            const arc0 = 0.0;
+            const arc1 = Math.PI * 0.5
+            const arc2 = Math.PI;
+            const arc3 = Math.PI * 1.5
+
+            cr.newSubPath();
+            cr.arc(width - borderRadius, borderRadius, borderRadius, arc3, arc0);
+            cr.arc(width - borderRadius, height - borderRadius, borderRadius, arc0, arc1);
+            cr.arc(borderRadius, height - borderRadius, borderRadius, arc1, arc2);
+            cr.arc(borderRadius, borderRadius, borderRadius, arc2, arc3);
+            cr.closePath();
+
+            cr.clip();
+            cr.fill();
+
+            return false;
+        });
+
         this._updatedTime = null;
         this._updatedTimeTimeoutId = 0;
 
@@ -125,17 +151,17 @@ var WeatherWidget = GObject.registerClass({
     _syncLeftRightButtons() {
         let hadjustment = this._forecastStack.visible_child.get_hadjustment();
         if ((hadjustment.get_upper() - hadjustment.get_lower()) == hadjustment.page_size) {
-            this._leftBox.hide();
-            this._rightBox.hide();
+            this._leftButton.hide();
+            this._rightButton.hide();
         } else if (hadjustment.value == hadjustment.get_lower()){
-            this._leftBox.hide();
-            this._rightBox.show();
+            this._leftButton.hide();
+            this._rightButton.show();
         } else if (hadjustment.value >= (hadjustment.get_upper() - hadjustment.page_size)){
-            this._leftBox.show();
-            this._rightBox.hide();
+            this._leftButton.show();
+            this._rightButton.hide();
         } else {
-            this._leftBox.show();
-            this._rightBox.show();
+            this._leftButton.show();
+            this._rightButton.show();
         }
     }
 
@@ -209,7 +235,8 @@ var WeatherWidget = GObject.registerClass({
         this._apparentLabel.label = _('Feels like %.0f°').format(apparentValue);
 
         let forecasts = info.get_forecast_list();
-        let tz = GLib.TimeZone.new(info.location.get_timezone().get_tzid());
+        let coords = info.location.get_coords();
+        let tz = GLib.TimeZone.new(GWeather.Location.get_world().find_nearest_city(coords[0], coords[1]).get_timezone().get_tzid());
         for (let t of ['hourly', 'daily'])
             this._forecasts[t].update(forecasts, tz);
 
