@@ -16,8 +16,10 @@
 // with Gnome Weather; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-pkg.initGettext();
 pkg.initFormat();
+pkg.initGettext();
+window.ngettext = imports.gettext.ngettext;
+
 pkg.require({ 'Gdk': '3.0',
               'Gio': '2.0',
               'GLib': '2.0',
@@ -26,6 +28,7 @@ pkg.require({ 'Gdk': '3.0',
               'GWeather': '3.0' });
 
 const ByteArray = imports.byteArray;
+const Handy = imports.gi.Handy;
 const Gdk = imports.gi.Gdk;
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
@@ -85,18 +88,17 @@ const Application = GObject.registerClass(
 
     vfunc_startup() {
         super.vfunc_startup();
+        Handy.init();
         // ensure the type before we call to GtkBuilder
         GWeather.LocationEntry;
 
         Util.loadStyleSheet('/org/gnome/Weather/application.css');
 
-        let settings = Gtk.Settings.get_for_screen(Gdk.Screen.get_default());
-        settings.gtk_application_prefer_dark_theme = true;
-
         this.world = GWeather.Location.get_world();
         this.model = new World.WorldModel(this.world, true);
-        this.model.load();
         this.currentLocationController = new CurrentLocationController.CurrentLocationController(this.model);
+        this.model.load();
+
 
         this.model.connect('notify::loading', () => {
             if (this.model.loading)
