@@ -16,6 +16,7 @@
 // with Gnome Weather; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
+const Handy = imports.gi.Handy;
 const Gio = imports.gi.Gio;
 const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
@@ -32,8 +33,11 @@ const Page = {
     CITY: 1
 };
 
-var MainWindow = GObject.registerClass(
-    class MainWindow extends Gtk.ApplicationWindow {
+var MainWindow = GObject.registerClass({
+    Template: 'resource:///org/gnome/Weather/window.ui',
+    InternalChildren: ['header', 'refreshRevealer', 'refresh', 'forecastStackSwitcher', 'stack',
+                       'titleStack', 'searchView', 'searchEntry', 'forecastStackSwitcherBar']
+}, class MainWindow extends Handy.ApplicationWindow {
 
     _init(params) {
         super._init(params);
@@ -64,54 +68,26 @@ var MainWindow = GObject.registerClass(
         refreshAction.connect('activate', () => this.update());
         this.add_action(refreshAction);
 
-        let builder = new Gtk.Builder();
-        builder.add_from_resource('/org/gnome/Weather/window.ui');
-        builder.add_from_resource('/org/gnome/Weather/primary-menu.ui');
+        this._model = this.application.model;
 
-        let grid = builder.get_object('main-panel');
-        this._header = builder.get_object('header-bar');
-        this.set_titlebar(this._header);
-        let [title, subtitle] = this._getTitle();
-        this._header.title = title;
-        this._header.subtitle = subtitle;
+        this._searchView.icon_name = pkg.name;
 
-        this._worldView = new WorldView.WorldContentView(this.application, this, { visible: true });
-        this._worldView.hide();
-
-        this._model = this._worldView.model;
-
-        this._searchView = builder.get_object('initial-grid');
-
-        this._searchEntry = builder.get_object('initial-grid-location-entry');
         this._searchEntry.connect('notify::location', (entry) => {
             this._searchLocationChanged(entry);
         });
 
-        let placesButton = builder.get_object('places-button');
-        this._pageWidgets[Page.CITY].push(placesButton);
+        this._pageWidgets[Page.CITY].push(this._refresh);
 
-        placesButton.set_popover(this._worldView);
+        this._cityView = new City.WeatherView(this.application, this,
+                                              { hexpand: true, vexpand: true });
+        this._stack.add_named(this._cityView, 'city');
 
-        let refresh = builder.get_object('refresh-button');
-        this._pageWidgets[Page.CITY].push(refresh);
+        this._forecastStackSwitcher.set_stack(this._cityView.getInfoPage().getForecastStack());
 
-        let primaryMenuModel = builder.get_object('primary-menu');
-        let primaryMenuButton = builder.get_object('primary-menu-button');
-        let popover = Gtk.Popover.new_from_model(primaryMenuButton, primaryMenuModel);
-
-        primaryMenuButton.set_popover(popover);
-
-        this._stack = builder.get_object('main-stack');
-
-        this._cityView = new City.WeatherView({ hexpand: true,
-                                                vexpand: true });
-        this._stack.add(this._cityView);
+        this._forecastStackSwitcherBar.set_stack(this._cityView.getInfoPage().getForecastStack());
 
         this._stack.set_visible_child(this._searchView);
 
-        this.add(grid);
-        grid.show_all();
-
         for (let i = 0; i < this._pageWidgets[Page.CITY].length; i++)
             this._pageWidgets[Page.CITY][i].hide();
 
@@ -121,6 +97,7 @@ var MainWindow = GObject.registerClass(
         }
 
         this._showingDefault = false;
+        this.show_all();
     }
 
     update() {
@@ -134,26 +111,6 @@ var MainWindow = GObject.registerClass(
         }
     }
 
-    _getTitle() {
-        if (this._currentPage == Page.SEARCH)
-            return [_("Select Location"), null];
-
-        let location = this._cityView.info.location;
-        let city = location;
-        if (location.get_level() == GWeather.LocationLevel.WEATHER_STATION)
-            city = location.get_parent();
-
-        let country = city.get_parent();
-        while (country &&
-               country.get_level() > GWeather.LocationLevel.COUNTRY)
-            country = country.get_parent();
-
-        if (country)
-            return [city.get_name(), country.get_name()];
-        else
-            return [city.get_name(), null];
-    }
-
     _goToPage(page) {
         for (let i = 0; i < this._pageWidgets[this._currentPage].length; i++)
             this._pageWidgets[this._currentPage][i].hide();
@@ -165,14 +122,11 @@ var MainWindow = GObject.registerClass(
         }
 
         this._currentPage = page;
-
-        let [title, subtitle] = this._getTitle();
-        this._header.title = title;
-        this._header.subtitle = subtitle;
     }
 
     showDefault() {
         this._showingDefault = true;
+        this._refreshRevealer.reveal_child = false;
         let clc = this.application.currentLocationController;
         let autoLocation = clc.autoLocation;
         let currentLocation = clc.currentLocation;
@@ -184,6 +138,7 @@ var MainWindow = GObject.registerClass(
 
     showSearch(text) {
         this._showingDefault = false;
+        this._refreshRevealer.reveal_child = true;
         this._cityView.setTimeVisible(false);
         this._stack.set_visible_child(this._searchView);
         this._goToPage(Page.SEARCH);
@@ -215,17 +170,10 @@ var MainWindow = GObject.registerClass(
         }
 
         this._showingDefault = false;
+        this._refreshRevealer.reveal_child = true;
         this.currentInfo = info;
         this._cityView.info = info;
 
-        let isCurrentTimezone = false;
-        let currentLocation = this.application.currentLocationController.currentLocation;
-        if (currentLocation) {
-            isCurrentTimezone = currentLocation.get_timezone().get_tzid() == info.location.get_timezone().get_tzid();
-        }
-        this._cityView.setTimeVisible(!isCurrentTimezone);
-
-        this._worldView.refilter();
         this._stack.set_visible_child(this._cityView);
         this._goToPage(Page.CITY);
     }
