@@ -59,22 +59,31 @@ def start():
 
     return app
 
+
 def reset_settings():
-    # need to go through the parser because pygobject does not handle maybe types
+    # need to go through the parser because pygobject
+    # does not handle maybe types
     parsed = GLib.Variant.parse(GLib.VariantType.new('av'),
                                 "[<(uint32 1, <('Linate Airport', 'LIML', "
                                 "false, @m(dd) (0.79296125100499293, "
-                                "0.16202472640904275), @m(dd) (0.79354303905785273, "
+                                "0.16202472640904275), @m(dd) "
+                                "(0.79354303905785273, "
                                 "0.16057029118347829))>)>]")
     settings.set_value("locations", parsed)
+    settings.set_value("automatic-location", GLib.Variant.new_boolean(False))
+
 
 def init():
-    global settings, _previous_locations
+    global settings, _previous_locations, _automatic_location
 
     settings = Gio.Settings("org.gnome.Weather")
     _previous_locations = settings.get_value("locations")
+    _automatic_location = settings.get_value("automatic-location")
     reset_settings()
 
+
 def fini():
     settings.set_value("locations", _previous_locations)
-    _do_bus_call("ActivateAction", GLib.Variant('(sava{sv})', ('quit', [], [])))
+    settings.set_value("automatic-location", _automatic_location)
+    _do_bus_call("ActivateAction",
+                 GLib.Variant('(sava{sv})', ('quit', [], [])))
